reduce_conjunction

Function reduce_conjunction 

pub fn reduce_conjunction(i: impl IntoIterator<Item = Gate>) -> Gate
Constructs a gate that evaluates to true if and only if all of the gates returned by i evaulate to true.

The construction has logarithmic depth in the length if i.